@@ -33,7 +33,7 @@ from yd_commands.type_check import check_list, check_str
 from yd_commands.utils import pathname_relative_to_config_file
 from yd_commands.validate_properties import validate_properties
 from yd_commands.variables import (
-    add_substitutions,
+    add_substitutions_without_overwriting,
     load_toml_file_with_variable_substitutions,
     process_variable_substitutions,
     process_variable_substitutions_insitu,
@@ -122,15 +122,15 @@ def load_config_common() -> ConfigCommon:
         # Note that add_substitutions() will perform all possible
         # substitutions for the items in its dictionary each time it's
         # called
-        add_substitutions(subs={URL: url})
+        add_substitutions_without_overwriting(subs={URL: url})
         key = process_variable_substitutions(common_section[KEY])
-        add_substitutions(subs={KEY: key})
+        add_substitutions_without_overwriting(subs={KEY: key})
         secret = process_variable_substitutions(common_section[SECRET])
-        add_substitutions(subs={SECRET: secret})
+        add_substitutions_without_overwriting(subs={SECRET: secret})
         namespace = process_variable_substitutions(common_section[NAMESPACE])
-        add_substitutions(subs={NAMESPACE: namespace})
+        add_substitutions_without_overwriting(subs={NAMESPACE: namespace})
         name_tag = process_variable_substitutions(common_section[NAME_TAG])
-        add_substitutions(subs={NAME_TAG: name_tag})
+        add_substitutions_without_overwriting(subs={NAME_TAG: name_tag})
 
         return ConfigCommon(
             # Required
@@ -239,6 +239,7 @@ def load_config_work_requirement() -> Optional[ConfigWorkRequirement]:
             completed_task_ttl=wr_section.get(COMPLETED_TASK_TTL, None),
             csv_files=csv_files,
             docker_env=wr_section.get(DOCKER_ENV, None),
+            docker_options=wr_section.get(DOCKER_OPTIONS, None),
             docker_password=wr_section.get(DOCKER_PASSWORD, None),
             docker_username=wr_section.get(DOCKER_USERNAME, None),
             env=wr_section.get(ENV, {}),
@@ -250,7 +251,6 @@ def load_config_work_requirement() -> Optional[ConfigWorkRequirement]:
             finish_if_any_task_failed=wr_section.get(FINISH_IF_ANY_TASK_FAILED, False),
             flatten_input_paths=wr_section.get(FLATTEN_PATHS, None),
             flatten_upload_paths=wr_section.get(FLATTEN_UPLOAD_PATHS, None),
-            fulfil_on_submit=wr_section.get(FULFIL_ON_SUBMIT, False),
             inputs_optional=wr_section.get(INPUTS_OPTIONAL, []),
             inputs_required=wr_section.get(INPUTS_REQUIRED, []),
             instance_types=wr_section.get(INSTANCE_TYPES, None),
@@ -273,6 +273,7 @@ def load_config_work_requirement() -> Optional[ConfigWorkRequirement]:
             task_timeout=wr_section.get(TASK_TIMEOUT, None),
             task_type=task_type,
             tasks_per_worker=wr_section.get(TASKS_PER_WORKER, None),
+            task_level_timeout=wr_section.get(TASK_LEVEL_TIMEOUT, None),
             upload_files=wr_section.get(UPLOAD_FILES, []),
             vcpus=wr_section.get(VCPUS, None),
             verify_at_start=wr_section.get(VERIFY_AT_START, []),
